package org.jeecg.modules.hotelbanner.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.hotelbanner.entity.HotelBanner;
import org.jeecg.modules.hotelbanner.service.IHotelBannerService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: hotel_banner
 * @Author: jeecg-boot
 * @Date:   2024-09-15
 * @Version: V1.0
 */
@Api(tags="hotel_banner")
@RestController
@RequestMapping("/hotelbanner/hotelBanner")
@Slf4j
public class HotelBannerController extends JeecgController<HotelBanner, IHotelBannerService> {
	@Autowired
	private IHotelBannerService hotelBannerService;
	
	/**
	 * 分页列表查询
	 *
	 * @param hotelBanner
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "hotel_banner-分页列表查询")
	@ApiOperation(value="hotel_banner-分页列表查询", notes="hotel_banner-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HotelBanner>> queryPageList(HotelBanner hotelBanner,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HotelBanner> queryWrapper = QueryGenerator.initQueryWrapper(hotelBanner, req.getParameterMap());
		Page<HotelBanner> page = new Page<HotelBanner>(pageNo, pageSize);
		IPage<HotelBanner> pageList = hotelBannerService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param hotelBanner
	 * @return
	 */
	@AutoLog(value = "hotel_banner-添加")
	@ApiOperation(value="hotel_banner-添加", notes="hotel_banner-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HotelBanner hotelBanner) {
		hotelBannerService.save(hotelBanner);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param hotelBanner
	 * @return
	 */
	@AutoLog(value = "hotel_banner-编辑")
	@ApiOperation(value="hotel_banner-编辑", notes="hotel_banner-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HotelBanner hotelBanner) {
		hotelBannerService.updateById(hotelBanner);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "hotel_banner-通过id删除")
	@ApiOperation(value="hotel_banner-通过id删除", notes="hotel_banner-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		hotelBannerService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "hotel_banner-批量删除")
	@ApiOperation(value="hotel_banner-批量删除", notes="hotel_banner-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.hotelBannerService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "hotel_banner-通过id查询")
	@ApiOperation(value="hotel_banner-通过id查询", notes="hotel_banner-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HotelBanner> queryById(@RequestParam(name="id",required=true) String id) {
		HotelBanner hotelBanner = hotelBannerService.getById(id);
		if(hotelBanner==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(hotelBanner);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param hotelBanner
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HotelBanner hotelBanner) {
        return super.exportXls(request, hotelBanner, HotelBanner.class, "hotel_banner");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HotelBanner.class);
    }

}
