package org.jeecg.modules.hotelcategoryitem.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.hotelcategoryitem.entity.HotelCategoryItem;
import org.jeecg.modules.hotelcategoryitem.service.IHotelCategoryItemService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: hotel_category_item
 * @Author: jeecg-boot
 * @Date:   2024-09-10
 * @Version: V1.0
 */
@Api(tags="hotel_category_item")
@RestController
@RequestMapping("/hotelcategoryitem/hotelCategoryItem")
@Slf4j
public class HotelCategoryItemController extends JeecgController<HotelCategoryItem, IHotelCategoryItemService> {
	@Autowired
	private IHotelCategoryItemService hotelCategoryItemService;
	
	/**
	 * 分页列表查询
	 *
	 * @param hotelCategoryItem
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "hotel_category_item-分页列表查询")
	@ApiOperation(value="hotel_category_item-分页列表查询", notes="hotel_category_item-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HotelCategoryItem>> queryPageList(HotelCategoryItem hotelCategoryItem,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HotelCategoryItem> queryWrapper = QueryGenerator.initQueryWrapper(hotelCategoryItem, req.getParameterMap());
		Page<HotelCategoryItem> page = new Page<HotelCategoryItem>(pageNo, pageSize);
		IPage<HotelCategoryItem> pageList = hotelCategoryItemService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param hotelCategoryItem
	 * @return
	 */
	@AutoLog(value = "hotel_category_item-添加")
	@ApiOperation(value="hotel_category_item-添加", notes="hotel_category_item-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HotelCategoryItem hotelCategoryItem) {
		hotelCategoryItemService.save(hotelCategoryItem);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param hotelCategoryItem
	 * @return
	 */
	@AutoLog(value = "hotel_category_item-编辑")
	@ApiOperation(value="hotel_category_item-编辑", notes="hotel_category_item-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HotelCategoryItem hotelCategoryItem) {
		hotelCategoryItemService.updateById(hotelCategoryItem);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "hotel_category_item-通过id删除")
	@ApiOperation(value="hotel_category_item-通过id删除", notes="hotel_category_item-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		hotelCategoryItemService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "hotel_category_item-批量删除")
	@ApiOperation(value="hotel_category_item-批量删除", notes="hotel_category_item-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.hotelCategoryItemService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "hotel_category_item-通过id查询")
	@ApiOperation(value="hotel_category_item-通过id查询", notes="hotel_category_item-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HotelCategoryItem> queryById(@RequestParam(name="id",required=true) String id) {
		HotelCategoryItem hotelCategoryItem = hotelCategoryItemService.getById(id);
		if(hotelCategoryItem==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(hotelCategoryItem);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param hotelCategoryItem
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HotelCategoryItem hotelCategoryItem) {
        return super.exportXls(request, hotelCategoryItem, HotelCategoryItem.class, "hotel_category_item");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HotelCategoryItem.class);
    }

}
