package org.jeecg.modules.hotelcoupon.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.hotelcoupon.entity.HotelCoupon;
import org.jeecg.modules.hotelcoupon.service.IHotelCouponService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: hotel_coupon
 * @Author: jeecg-boot
 * @Date:   2024-10-14
 * @Version: V1.0
 */
@Api(tags="hotel_coupon")
@RestController
@RequestMapping("/hotelcoupon/hotelCoupon")
@Slf4j
public class HotelCouponController extends JeecgController<HotelCoupon, IHotelCouponService> {
	@Autowired
	private IHotelCouponService hotelCouponService;
	
	/**
	 * 分页列表查询
	 *
	 * @param hotelCoupon
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "hotel_coupon-分页列表查询")
	@ApiOperation(value="hotel_coupon-分页列表查询", notes="hotel_coupon-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HotelCoupon>> queryPageList(HotelCoupon hotelCoupon,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HotelCoupon> queryWrapper = QueryGenerator.initQueryWrapper(hotelCoupon, req.getParameterMap());
		Page<HotelCoupon> page = new Page<HotelCoupon>(pageNo, pageSize);
		IPage<HotelCoupon> pageList = hotelCouponService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param hotelCoupon
	 * @return
	 */
	@AutoLog(value = "hotel_coupon-添加")
	@ApiOperation(value="hotel_coupon-添加", notes="hotel_coupon-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HotelCoupon hotelCoupon) {
		hotelCouponService.save(hotelCoupon);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param hotelCoupon
	 * @return
	 */
	@AutoLog(value = "hotel_coupon-编辑")
	@ApiOperation(value="hotel_coupon-编辑", notes="hotel_coupon-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HotelCoupon hotelCoupon) {
		hotelCouponService.updateById(hotelCoupon);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "hotel_coupon-通过id删除")
	@ApiOperation(value="hotel_coupon-通过id删除", notes="hotel_coupon-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		hotelCouponService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "hotel_coupon-批量删除")
	@ApiOperation(value="hotel_coupon-批量删除", notes="hotel_coupon-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.hotelCouponService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "hotel_coupon-通过id查询")
	@ApiOperation(value="hotel_coupon-通过id查询", notes="hotel_coupon-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HotelCoupon> queryById(@RequestParam(name="id",required=true) String id) {
		HotelCoupon hotelCoupon = hotelCouponService.getById(id);
		if(hotelCoupon==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(hotelCoupon);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param hotelCoupon
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HotelCoupon hotelCoupon) {
        return super.exportXls(request, hotelCoupon, HotelCoupon.class, "hotel_coupon");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HotelCoupon.class);
    }

}
