package org.jeecg.modules.hotelcouponlog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.hotelcouponlog.entity.HotelCouponLog;
import org.jeecg.modules.hotelcouponlog.service.IHotelCouponLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: hotel_coupon_log
 * @Author: jeecg-boot
 * @Date:   2024-10-14
 * @Version: V1.0
 */
@Api(tags="hotel_coupon_log")
@RestController
@RequestMapping("/hotelcouponlog/hotelCouponLog")
@Slf4j
public class HotelCouponLogController extends JeecgController<HotelCouponLog, IHotelCouponLogService> {
	@Autowired
	private IHotelCouponLogService hotelCouponLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param hotelCouponLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "hotel_coupon_log-分页列表查询")
	@ApiOperation(value="hotel_coupon_log-分页列表查询", notes="hotel_coupon_log-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HotelCouponLog>> queryPageList(HotelCouponLog hotelCouponLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HotelCouponLog> queryWrapper = QueryGenerator.initQueryWrapper(hotelCouponLog, req.getParameterMap());
		Page<HotelCouponLog> page = new Page<HotelCouponLog>(pageNo, pageSize);
		IPage<HotelCouponLog> pageList = hotelCouponLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param hotelCouponLog
	 * @return
	 */
	@AutoLog(value = "hotel_coupon_log-添加")
	@ApiOperation(value="hotel_coupon_log-添加", notes="hotel_coupon_log-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HotelCouponLog hotelCouponLog) {
		hotelCouponLogService.save(hotelCouponLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param hotelCouponLog
	 * @return
	 */
	@AutoLog(value = "hotel_coupon_log-编辑")
	@ApiOperation(value="hotel_coupon_log-编辑", notes="hotel_coupon_log-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HotelCouponLog hotelCouponLog) {
		hotelCouponLogService.updateById(hotelCouponLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "hotel_coupon_log-通过id删除")
	@ApiOperation(value="hotel_coupon_log-通过id删除", notes="hotel_coupon_log-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		hotelCouponLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "hotel_coupon_log-批量删除")
	@ApiOperation(value="hotel_coupon_log-批量删除", notes="hotel_coupon_log-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.hotelCouponLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "hotel_coupon_log-通过id查询")
	@ApiOperation(value="hotel_coupon_log-通过id查询", notes="hotel_coupon_log-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HotelCouponLog> queryById(@RequestParam(name="id",required=true) String id) {
		HotelCouponLog hotelCouponLog = hotelCouponLogService.getById(id);
		if(hotelCouponLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(hotelCouponLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param hotelCouponLog
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HotelCouponLog hotelCouponLog) {
        return super.exportXls(request, hotelCouponLog, HotelCouponLog.class, "hotel_coupon_log");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HotelCouponLog.class);
    }

}
