package org.jeecg.modules.hotelgoods.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.hotelgoods.entity.HotelGoods;
import org.jeecg.modules.hotelgoods.service.IHotelGoodsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: hotel_goods
 * @Author: jeecg-boot
 * @Date:   2024-09-11
 * @Version: V1.0
 */
@Api(tags="hotel_goods")
@RestController
@RequestMapping("/hotelgoods/hotelGoods")
@Slf4j
public class HotelGoodsController extends JeecgController<HotelGoods, IHotelGoodsService> {
	@Autowired
	private IHotelGoodsService hotelGoodsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param hotelGoods
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "hotel_goods-分页列表查询")
	@ApiOperation(value="hotel_goods-分页列表查询", notes="hotel_goods-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HotelGoods>> queryPageList(HotelGoods hotelGoods,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HotelGoods> queryWrapper = QueryGenerator.initQueryWrapper(hotelGoods, req.getParameterMap());
		Page<HotelGoods> page = new Page<HotelGoods>(pageNo, pageSize);
		IPage<HotelGoods> pageList = hotelGoodsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param hotelGoods
	 * @return
	 */
	@AutoLog(value = "hotel_goods-添加")
	@ApiOperation(value="hotel_goods-添加", notes="hotel_goods-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HotelGoods hotelGoods) {
		hotelGoodsService.save(hotelGoods);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param hotelGoods
	 * @return
	 */
	@AutoLog(value = "hotel_goods-编辑")
	@ApiOperation(value="hotel_goods-编辑", notes="hotel_goods-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HotelGoods hotelGoods) {
		hotelGoodsService.updateById(hotelGoods);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "hotel_goods-通过id删除")
	@ApiOperation(value="hotel_goods-通过id删除", notes="hotel_goods-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		hotelGoodsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "hotel_goods-批量删除")
	@ApiOperation(value="hotel_goods-批量删除", notes="hotel_goods-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.hotelGoodsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "hotel_goods-通过id查询")
	@ApiOperation(value="hotel_goods-通过id查询", notes="hotel_goods-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HotelGoods> queryById(@RequestParam(name="id",required=true) String id) {
		HotelGoods hotelGoods = hotelGoodsService.getById(id);
		if(hotelGoods==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(hotelGoods);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param hotelGoods
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HotelGoods hotelGoods) {
        return super.exportXls(request, hotelGoods, HotelGoods.class, "hotel_goods");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HotelGoods.class);
    }

}
